@@ -61,6 +61,7 @@ ergm.getCluster <- function(control, verbose=FALSE){
                    ergm.MPIcluster.started(TRUE)
                    makeCluster(control$parallel,type="MPI")
                  }else
+                   ergm.MPIcluster.started(FALSE)
                    getMPIcluster()
                },
                SOCK={
@@ -105,7 +106,10 @@ ergm.stopCluster <- function(object, ...)
 
 # Only stop the MPI cluster if we were the ones who had started it.
 ergm.stopCluster.MPIcluster <- function(object, ...){
-  if(ergm.MPIcluster.started()) stopCluster(object)
+  if(ergm.MPIcluster.started()){
+    ergm.MPIcluster.started(FALSE)
+    stopCluster(object)
+  }
 }
 
 ergm.stopCluster.default <- function(object, ...){
@@ -115,7 +119,6 @@ ergm.stopCluster.default <- function(object, ...){
 
 
 ergm.sample.tomcmc<-function(sample, params){
-  library(coda)
   samplesize <- nrow(sample)
   if(params$parallel){
 
