@@ -1,14 +1,24 @@
-#  File ergm/R/print.ergm.R
-#  Part of the statnet package, http://statnet.org
+#  File R/print.ergm.R in package ergm, part of the Statnet suite
+#  of packages for network analysis, http://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnet.org/attribution
+#  open source, and has the attribution requirements (GPL Section 7) at
+#  http://statnet.org/attribution
 #
-#  Copyright 2012 the statnet development team
-######################################################################
+#  Copyright 2003-2013 Statnet Commons
+#######################################################################
 ###############################################################################
 # The <print.ergm> function prints summary information for a given ergm
+#
+# --PARAMETERS--
+#   x     :  an ergm object
+#   digits:  the number of significant digits for the coefficients;
+#            default=max(3, getOption("digits")-3)
+#   ...   :  additional parameters passed from within; these will be ignored
+#
+# --RETURNED--
+#   x
+# 
 ###############################################################################
 
 print.ergm <- function (x, digits = max(3, getOption("digits") - 3), ...) {
@@ -28,15 +38,10 @@ print.ergm <- function (x, digits = max(3, getOption("digits") - 3), ...) {
 #    if (!is.null(x$iterations)) {
 #      cat("Newton-Raphson iterations: ", x$iterations[1], "\n")
 #    }
-    if(!all(x$theta1$independent)){
-     cat("\nMPLE Coefficients:\n")
+
+     cat("\n",x$estimate," Coefficients:\n",sep="")
      print.default(format(x$coef, digits = digits), print.gap = 2, 
          quote = FALSE)
-    }else{
-    cat("\nMLE Coefficients:\n")
-    print.default(format(x$coef, digits = digits), print.gap = 2, 
-        quote = FALSE)
-    }
    }
   }
   else {
