@@ -1,12 +1,11 @@
-/*
- *  File ergm/src/edgetree.c
- *  Part of the statnet package, http://statnetproject.org
+/*  File src/edgetree.c in package ergm, part of the Statnet suite
+ *  of packages for network analysis, http://statnet.org .
  *
  *  This software is distributed under the GPL-3 license.  It is free,
- *  open source, and has the attribution requirements (GPL Section 7) in
- *    http://statnetproject.org/attribution
+ *  open source, and has the attribution requirements (GPL Section 7) at
+ *  http://statnet.org/attribution
  *
- *  Copyright 2011 the statnet development team
+ *  Copyright 2003-2013 Statnet Commons
  */
 #include "edgetree.h"
 
@@ -22,11 +21,11 @@
  that the 0th TreeNode in the array is unused and should 
  have all its values set to zero
 *******************/
+/* *** don't forget, tail -> head */
+
 Network NetworkInitialize(Vertex *tails, Vertex *heads, Edge nedges, 
 			  Vertex nnodes, int directed_flag, Vertex bipartite,
-			  int lasttoggle_flag) {
-
-  /* *** don't forget, tail -> head */
+			  int lasttoggle_flag, int time, int *lasttoggle) {
 
   Network nw;
 
@@ -42,8 +41,10 @@ Network NetworkInitialize(Vertex *tails, Vertex *heads, Edge nedges,
   GetRNGstate();  /* R function enabling uniform RNG */
 
   if(lasttoggle_flag){
-    nw.duration_info.MCMCtimer=0;
-    nw.duration_info.lasttoggle = (int *) calloc(directed_flag? nnodes*(nnodes-1) : (nnodes*(nnodes-1))/2, sizeof(int));
+    nw.duration_info.time=time;
+    nw.duration_info.lasttoggle = (int *) calloc(DYADCOUNT(nnodes, bipartite, directed_flag), sizeof(int));
+    if(lasttoggle)
+      memcpy(nw.duration_info.lasttoggle, lasttoggle, DYADCOUNT(nnodes, bipartite, directed_flag) * sizeof(int));
   }
   else nw.duration_info.lasttoggle = NULL;
 
@@ -74,7 +75,7 @@ Network NetworkInitialize(Vertex *tails, Vertex *heads, Edge nedges,
 /*Takes vectors of doubles for edges; used only when constructing from inputparams. */
 Network NetworkInitializeD(double *tails, double *heads, Edge nedges,
 			  Vertex nnodes, int directed_flag, Vertex bipartite,
-			  int lasttoggle_flag) {
+			  int lasttoggle_flag, int time, int *lasttoggle) {
 
   /* *** don't forget, tail -> head */
 
@@ -86,7 +87,7 @@ Network NetworkInitializeD(double *tails, double *heads, Edge nedges,
     iheads[i]=heads[i];
   }
 
-  Network nw=NetworkInitialize(itails,iheads,nedges,nnodes,directed_flag,bipartite,lasttoggle_flag);
+  Network nw=NetworkInitialize(itails,iheads,nedges,nnodes,directed_flag,bipartite,lasttoggle_flag, time, lasttoggle);
 
   free(itails);
   free(iheads);
@@ -128,16 +129,16 @@ Network *NetworkCopy(Network *dest, Network *src){
   memcpy(dest->outedges, src->outedges, maxedges*sizeof(TreeNode));
 
   int directed_flag = dest->directed_flag = src->directed_flag;
+  Vertex bipartite = dest->bipartite = src->bipartite;
 
   if(src->duration_info.lasttoggle){
-    dest->duration_info.MCMCtimer=src->duration_info.MCMCtimer;
-    dest->duration_info.lasttoggle = (int *) calloc(directed_flag? nnodes*(nnodes-1) : (nnodes*(nnodes-1))/2, sizeof(int));
-    memcpy(dest->duration_info.lasttoggle, src->duration_info.lasttoggle,(directed_flag? nnodes*(nnodes-1) : (nnodes*(nnodes-1))/2) * sizeof(int));
+    dest->duration_info.time=src->duration_info.time;
+    dest->duration_info.lasttoggle = (int *) calloc(DYADCOUNT(nnodes, bipartite, directed_flag), sizeof(int));
+    memcpy(dest->duration_info.lasttoggle, src->duration_info.lasttoggle,DYADCOUNT(nnodes, bipartite, directed_flag) * sizeof(int));
   }
   else dest->duration_info.lasttoggle = NULL;
 
   dest->nedges = src->nedges;
-  dest->bipartite = src->bipartite;
 
   return dest;
 }
@@ -156,8 +157,7 @@ Edge EdgetreeSearch (Vertex a, Vertex b, TreeNode *edges) {
 
   es = edges + e;
   v = es->value;
-  while(e != 0 && b != v)
-    {
+  while(e != 0 && b != v)  {
       e = (b<v)?  es->left : es->right;
       es = edges + e;
       v = es->value;
@@ -184,6 +184,25 @@ Edge EdgetreeSuccessor (TreeNode *edges, Edge x) {
   return y; 
 }   
 
+/*****************
+ Edge EdgetreePredecessor
+
+ Return the index of the TreeNode with the smallest value
+ greater than edges[x].value in the same edge tree, or 0
+ if none.  This is used by (for instance)
+ the DeleteHalfedgeFromTree function.
+*****************/
+Edge EdgetreePredecessor (TreeNode *edges, Edge x) {
+  TreeNode *ptr;
+  Edge y;
+
+  if ((y=(ptr=edges+x)->left) != 0) 
+    return EdgetreeMaximum (edges, y);
+  while ((y=ptr->parent)!=0 && x==(ptr=edges+y)->left) 
+    x=y;
+  return y; 
+}   
+
 /*****************
  Edge EdgetreeMinimum
 
@@ -198,7 +217,19 @@ Edge EdgetreeMinimum (TreeNode *edges, Edge x) {
   return x;
 }
 
+/*****************
+ Edge EdgetreeMaximum
 
+ Return the index of the TreeNode with the
+ greatest value in the subtree rooted at x
+*****************/
+Edge EdgetreeMaximum (TreeNode *edges, Edge x) {
+  Edge y;
+
+  while ((y=(edges+x)->right) != 0)
+    x=y;
+  return x;
+}
 
 /* *** don't forget, edges are now given by tails -> heads, and as
        such, the function definitions now require tails to be passed
@@ -212,6 +243,9 @@ Edge EdgetreeMinimum (TreeNode *edges, Edge x) {
  Toggle an edge:  Set it to the opposite of its current
  value.  Return 1 if edge added, 0 if deleted.
 *****************/
+
+/* *** don't forget tail->head, so this function now accepts tail before head */
+
 int ToggleEdge (Vertex tail, Vertex head, Network *nwp) 
 {
   /* don't forget tails < heads now for undirected networks */
@@ -241,6 +275,9 @@ int ToggleEdge (Vertex tail, Vertex head, Network *nwp)
  Same as ToggleEdge, but this time with the additional
  step of updating the matrix of 'lasttoggle' times
  *****************/
+
+/* *** don't forget tail->head, so this function now accepts tail before head */
+
 int ToggleEdgeWithTimestamp(Vertex tail, Vertex head, Network *nwp){
   Edge k;
 
@@ -253,11 +290,15 @@ int ToggleEdgeWithTimestamp(Vertex tail, Vertex head, Network *nwp){
   }
   
   if(nwp->duration_info.lasttoggle){ /* Skip timestamps if no duration info. */
-    if (nwp->directed_flag) 
-      k = (head-1)*(nwp->nnodes-1) + tail - ((tail>head) ? 1:0) - 1; 
-    else
-      k = (head-1)*(head-2)/2 + tail - 1;    
-    nwp->duration_info.lasttoggle[k] = nwp->duration_info.MCMCtimer;
+    if(nwp->bipartite){
+      k = (head-nwp->bipartite-1)*(nwp->bipartite) + tail - 1;
+    }else{
+      if (nwp->directed_flag) 
+	k = (head-1)*(nwp->nnodes-1) + tail - ((tail>head) ? 1:0) - 1; 
+      else
+	k = (head-1)*(head-2)/2 + tail - 1;    
+    }
+    nwp->duration_info.lasttoggle[k] = nwp->duration_info.time;
   }
   
   if (AddEdgeToTrees(tail,head,nwp))
@@ -280,6 +321,9 @@ int ToggleEdgeWithTimestamp(Vertex tail, Vertex head, Network *nwp){
  Return time since given (tail,head) was last toggled using
  ToggleEdgeWithTimestamp function
 *****************/
+
+/* *** don't forget tail->head, so this function now accepts tail before head */
+
 int ElapsedTime(Vertex tail, Vertex head, Network *nwp){
   Edge k;
   /* don't forget, tails < heads now in undirected networks */
@@ -291,11 +335,15 @@ int ElapsedTime(Vertex tail, Vertex head, Network *nwp){
   }
 
   if(nwp->duration_info.lasttoggle){ /* Return 0 if no duration info. */
-    if (nwp->directed_flag) 
-      k = (head-1)*(nwp->nnodes-1) + tail - ((tail>head) ? 1:0) - 1; 
-    else
-      k = (head-1)*(head-2)/2 + tail - 1;    
-    return nwp->duration_info.MCMCtimer - nwp->duration_info.lasttoggle[k];
+    if(nwp->bipartite){
+      k = (head-nwp->bipartite-1)*(nwp->bipartite) + tail - 1;
+    }else{
+      if (nwp->directed_flag) 
+	k = (head-1)*(nwp->nnodes-1) + tail - ((tail>head) ? 1:0) - 1; 
+      else
+	k = (head-1)*(head-2)/2 + tail - 1;    
+    }
+    return nwp->duration_info.time - nwp->duration_info.lasttoggle[k];
   }
   else return 0; 
   /* Should maybe return an error code of some sort, since 0 elapsed time
@@ -316,14 +364,20 @@ int ElapsedTime(Vertex tail, Vertex head, Network *nwp){
  Set an edge's time-stamp to the current MCMC time.
  *****************/
 
+/* *** don't forget tail->head, so this function now accepts tail before head */
+
 void TouchEdge(Vertex tail, Vertex head, Network *nwp){
   unsigned int k;
   if(nwp->duration_info.lasttoggle){ /* Skip timestamps if no duration info. */
-    if (nwp->directed_flag) 
-      k = (head-1)*(nwp->nnodes-1) + tail - ((tail>head) ? 1:0) - 1; 
-    else
-      k = (head-1)*(head-2)/2 + tail - 1;    
-    nwp->duration_info.lasttoggle[k] = nwp->duration_info.MCMCtimer;
+    if(nwp->bipartite){
+      k = (head-nwp->bipartite-1)*(nwp->bipartite) + tail - 1;
+    }else{
+      if (nwp->directed_flag) 
+	k = (head-1)*(nwp->nnodes-1) + tail - ((tail>head) ? 1:0) - 1; 
+      else
+	k = (head-1)*(head-2)/2 + tail - 1;    
+    }
+    nwp->duration_info.lasttoggle[k] = nwp->duration_info.time;
   }
 }
 
@@ -342,6 +396,9 @@ void TouchEdge(Vertex tail, Vertex head, Network *nwp){
  inedges, this actually involves two calls to AddHalfedgeToTree (hence
  "Trees" instead of "Tree" in the name of this function).
 *****************/
+
+/* *** don't forget tail->head, so this function now accepts tail before head */
+
 int AddEdgeToTrees(Vertex tail, Vertex head, Network *nwp){
   if (EdgetreeSearch(tail, head, nwp->outedges) == 0) {
     AddHalfedgeToTree(tail, head, nwp->outedges, nwp->next_outedge);
@@ -382,8 +439,7 @@ void AddHalfedgeToTree (Vertex a, Vertex b, TreeNode *edges, Edge next_edge){
 void UpdateNextedge
 *****************/
 void UpdateNextedge (TreeNode *edges, Edge *nextedge, Network *nwp) {
-  int mult=2;
-  /*TreeNode *tmp_in, *tmp_out; */
+  const unsigned int mult=2;
   
   while (++*nextedge < nwp->maxedges) {
     if (edges[*nextedge].value==0) return;
@@ -415,6 +471,9 @@ void UpdateNextedge (TreeNode *edges, Edge *nextedge, Network *nwp) {
  Return 1 if successful, 0 otherwise.  As with AddEdgeToTrees, this must
  be done once for outedges and once for inedges.
 *****************/
+
+/* *** don't forget tail->head, so this function now accepts tail before head */
+
 int DeleteEdgeFromTrees(Vertex tail, Vertex head, Network *nwp){
   if (DeleteHalfedgeFromTree(tail, head, nwp->outedges,&(nwp->next_outedge))&&
       DeleteHalfedgeFromTree(head, tail, nwp->inedges, &(nwp->next_inedge))) {
@@ -443,7 +502,10 @@ int DeleteHalfedgeFromTree(Vertex a, Vertex b, TreeNode *edges,
   /* First, determine which node to splice out; this is z.  If the current
      z has two children, then we'll actually splice out its successor. */
   if ((zptr=edges+z)->left != 0 && zptr->right != 0) {
-    z=EdgetreeSuccessor(edges, z);  
+    if(unif_rand()<0.5)
+      z=EdgetreeSuccessor(edges, z);  
+    else
+      z=EdgetreePredecessor(edges, z);  
     zptr->value = (ptr=edges+z)->value;
     zptr=ptr;
   }
@@ -546,27 +608,79 @@ Edge DesignMissing (Vertex a, Vertex b, Network *mnwp) {
   Note that i is numbered from 1, not 0.  Thus, the maximum possible
   value of i is nwp->nedges.
 ******************/
+
+/* *** don't forget tail->head, so this function now accepts tail before head */
+
 int FindithEdge (Vertex *tail, Vertex *head, Edge i, Network *nwp) {
-  Vertex head1=1;
+  Vertex taili=1;
   Edge e;
 
+  /* TODO: This could be speeded up by a factor of 3 or more by starting
+     the search from the tail n rather than tail 1 if i > ndyads/2. */
+
   if (i > nwp->nedges || i<=0)
     return 0;
-  while (i > nwp->outdegree[head1]) {
-    i -= nwp->outdegree[head1];
-    head1++;
+  while (i > nwp->outdegree[taili]) {
+    i -= nwp->outdegree[taili];
+    taili++;
   }
-  e=EdgetreeMinimum(nwp->outedges,head1);
+
+  /* TODO: This could be speeded up by a factor of 3 or more by starting
+     the search from the tree maximum rather than minimum (left over) i > outdegree[taili]. */
+
+  e=EdgetreeMinimum(nwp->outedges,taili);
   while (i-- > 1) {
     e=EdgetreeSuccessor(nwp->outedges, e);
   }
-  *tail = head1;
+  *tail = taili;
   *head = nwp->outedges[e].value;
   return 1;
 }
 
 /*****************
-  int FindithnonEdge
+  int GetRandEdge
+
+  Select an edge in the Network *nwp at random and update the values
+  of tail and head appropriately. Return 1 if successful, 0 otherwise.
+******************/
+
+/* *** don't forget tail->head, so this function now accepts tail before head */
+
+int GetRandEdge(Vertex *tail, Vertex *head, Network *nwp) {
+  if(nwp->nedges==0) return(0);
+  // FIXME: The constant maxEattempts needs to be tuned.
+  const unsigned int maxEattempts=10;
+  unsigned int Eattempts = (nwp->maxedges-1)/nwp->nedges;
+  Edge rane;
+  
+  if(Eattempts>maxEattempts){
+    // If the outedges is too sparse, revert to the old algorithm.
+    rane=1 + unif_rand() * nwp->nedges;
+    FindithEdge(tail, head, rane, nwp);
+  }else{
+    // Otherwise, find a TreeNode which has a head.
+    do{
+      // Note that the outedges array has maxedges elements, but the
+      // 0th one is always blank, so there is actually space for
+      // maxedges-1 nodes.
+      rane = 1 + unif_rand() * (nwp->maxedges-1);
+    }while(nwp->outedges[rane].value==0);
+
+    // Form the head.
+    *head=nwp->outedges[rane].value;
+    
+    // Ascend the edgetree as long as we can.
+    // Note that it will stop as soon as rane no longer has a parent,
+    // _before_ overwriting it.
+    while(nwp->outedges[rane].parent) rane=nwp->outedges[rane].parent;
+    // Then, the position of the root is the tail of edge.
+    *tail=rane;
+  }
+  return 1;
+}
+
+/*****************
+  int FindithNonedge
 
   Find the ith nonedge in the Network *nwp and
   update the values of tail and head appropriately.  Return
@@ -577,12 +691,101 @@ int FindithEdge (Vertex *tail, Vertex *head, Edge i, Network *nwp) {
 
 /* This function is not yet written.  It's not clear whether it'll
    be needed. */      
+  /* *** but if it is needed, don't forget,  tail -> head */
 
-/* int FindithnonEdge (Vertex *tail, Vertex *head, Edge i, Network *nwp) {
-} */
+int FindithNonedge (Vertex *tail, Vertex *head, Edge i, Network *nwp) {
+  Vertex taili=1;
+  Edge e;
+  Edge ndyads = DYADCOUNT(nwp->nnodes, nwp->bipartite, nwp->directed_flag);
+  
+  // If the index is too high or too low, exit immediately.
+  if (i > ndyads - nwp->nedges || i<=0)
+    return 0;
 
+  /* TODO: This could be speeded up by a factor of 3 or more by starting
+     the search from the tail n rather than tail 1 if i > ndyads/2. */
 
+  Vertex nnt;
+  while (i > (nnt = nwp->nnodes - (nwp->bipartite ? nwp->bipartite : (nwp->directed_flag?1:taili))
+	      - nwp->outdegree[taili])) {   // nnt is the number of nonties incident on taili. Note that when network is undirected, tail<head.
+    i -= nnt;
+    taili++;
+  }
 
+  // Now, our tail is taili.
+
+  /* TODO: This could be speeded up by a factor of 3 or more by starting
+     the search from the tree maximum rather than minimum (left over) i > outdegree[taili]. */
+
+  // If taili 1, then head cannot be 1. If undirected, the smallest it can be is taili+1. If bipartite, the smallest it can be is nwp->bipartite+1.
+  Vertex lhead = (
+		  nwp->bipartite ? 
+		  nwp->bipartite :
+		  (nwp->directed_flag ?
+		   taili==1 : taili)
+		  );
+  e = EdgetreeMinimum(nwp->outedges,taili);
+  Vertex rhead = nwp->outedges[e].value;
+  // Note that rhead-lhead-1-(lhead<taili && taili<rhead) is the number of nonties between two successive ties.
+  // the -(lhead<taili && taili<rhead) is because (taili,taili) is not a valid nontie and must be skipped.
+  // Note that if taili is an isolate, rhead will be 0.
+  while (rhead && i > rhead-lhead-1-(lhead<taili && taili<rhead)) {
+    i -= rhead-lhead-1-(lhead<taili && taili<rhead);
+    lhead = rhead;
+    e = EdgetreeSuccessor(nwp->outedges, e);
+    // If rhead was the highest-indexed head, then e is now 0.
+    if(e) rhead = nwp->outedges[e].value;
+    else break; // Note that we don't actually need rhead in the final step.
+  }
+
+  // Now, the head we are looking for is (left over) i after lhead.
+
+  *tail = taili;
+  *head = lhead + i + (nwp->directed_flag && lhead+i>=taili); // Skip over the (taili,taili) dyad, if the network is directed.
+
+  return 1;
+}
+
+/*****************
+  int GetRandNonedge
+
+  Select an non-edge in the Network *nwp at random and update the values
+  of tail and head appropriately. Return 1 if successful, 0 otherwise.
+******************/
+
+/* *** don't forget tail->head, so this function now accepts tail before head */
+
+int GetRandNonedge(Vertex *tail, Vertex *head, Network *nwp) {
+  Edge ndyads = DYADCOUNT(nwp->nnodes, nwp->bipartite, nwp->directed_flag);
+  if(ndyads-nwp->nedges==0) return(0);
+
+  /* There are two ways to get a random nonedge: 1) keep trying dyads
+     at random until you find one that's not an edge or 2) generate i
+     at random and find ith nonedge. Method 1 works better in sparse
+     networks, while Method 2, which runs in deterministic time, works
+     better in dense networks.
+
+     The expected number of attempts for Method 1 is 1/(1-e/d) =
+     d/(d-e), where e is the number of edges and d is the number of
+     dyads.
+  */
+
+  // FIXME: The constant maxEattempts needs to be tuned.
+  const unsigned int maxEattempts=10;
+  unsigned int Eattempts = ndyads/(ndyads-nwp->nedges);
+  Edge rane;
+  
+  if(Eattempts>maxEattempts){
+    // If the network is too dense, use the deterministic-time method:
+    rane=1 + unif_rand() * (ndyads-nwp->nedges);
+    FindithNonedge(tail, head, rane, nwp);
+  }else{
+    do{
+      GetRandDyad(tail, head, nwp);
+    }while(EdgetreeSearch(*tail, *head, nwp->outedges));
+  }
+  return 1;
+}
 
 /* *** don't forget, edges are now given by tails -> heads, and as
        such, the function definitions now require tails to be passed
@@ -597,6 +800,8 @@ int FindithEdge (Vertex *tail, Vertex *head, Edge i, Network *nwp) {
 ****************/
 Edge EdgeTree2EdgeList(Vertex *tails, Vertex *heads, Network *nwp, Edge nmax){
   Edge nextedge=0;
+
+  /* *** don't forget,  tail -> head */
   if (nwp->directed_flag) {
     for (Vertex v=1; v<=nwp->nnodes; v++){
       for(Vertex e = EdgetreeMinimum(nwp->outedges, v);
@@ -635,8 +840,9 @@ Edge EdgeTree2EdgeList(Vertex *tails, Vertex *heads, Network *nwp, Edge nmax){
 
 
 void ShuffleEdges(Vertex *tails, Vertex *heads, Edge nedges){
+  /* *** don't forget,  tail -> head */
   for(Edge i = nedges; i > 0; i--) {
-    Edge j = (double) i * unif_rand();  /* shuffle to avoid worst-case performance */
+    Edge j = i * unif_rand();
     Vertex tail = tails[j];
     Vertex head = heads[j];
     tails[j] = tails[i-1];
